@@ -1,8 +1,9 @@
 from labelbase import Client as baseClient
 from labelbox import Client
 import pandas
-from tqdm import tqdm
 from concurrent.futures import ThreadPoolExecutor, as_completed
+from tqdm import tqdm
+import math
 
 def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_client:baseClient, row_data_col:str, 
                        global_key_col:str="", external_id_col:str="", metadata_index:dict={}, local_files:bool=False, divider:str="///", verbose=False):
@@ -28,24 +29,25 @@ def create_upload_dict(df:pandas.core.frame.DataFrame, lb_client:Client, base_cl
     metadata_schema_to_name_key = base_client.get_metadata_schema_to_name_key(lb_mdo=False, divider=divider, invert=False)
     metadata_name_key_to_schema = base_client.get_metadata_schema_to_name_key(lb_mdo=False, divider=divider, invert=True) 
     global_key_to_upload_dict = {}
-    futures = []
     with ThreadPoolExecutor() as exc:
-        for index, row in df.iterrows():
-            futures.append(
-                exc.submit(
-                    create_data_rows, lb_client, base_client, row, 
-                    metadata_name_key_to_schema, metadata_schema_to_name_key, row_data_col, 
-                    global_key_col, external_id_col, metadata_index, local_files, divider
-                )
-            )
+        futures = []
+        x = 0
+        dupe_print = 0
         if verbose:
-            for f in tqdm(as_completed(futures)):
-                res = f.result()
-                global_key_to_upload_dict[str(res["global_key"])] = res      
-        else:
-            for f in as_completed(futures):
-                res = f.result()
-                global_key_to_upload_dict[str(res["global_key"])] = res             
+            print(f'Submitting data rows...')
+        for index, row in df.iterrows():
+            futures.append(exc.submit(create_data_rows, lb_client, base_client, row, metadata_name_key_to_schema, metadata_schema_to_name_key, row_data_col, global_key_col, external_id_col, metadata_index, local_files, divider))
+        if verbose:
+            print(f'Processing data rows...')        
+        for f in as_completed(futures):
+            res = f.result()
+            global_key_to_upload_dict[str(res["global_key"])] = res    
+            if verbose:
+                x += 1
+                percent_complete = math.ceil((x / len(df)*100))
+                if percent_complete%1 == 0 and (percent_complete!=dupe_print):
+                    print(f'{str(percent_complete)}% complete')          
+                    dupe_print = percent_complete
     if verbose:
         print(f'Generated upload list - {len(global_key_to_upload_dict)} data rows to upload')
     return global_key_to_upload_dict  
@@ -69,7 +71,8 @@ def create_data_rows(lb_client:Client, base_client:baseClient, row:pandas.core.s
     Returns:
         Two items - the global_key, and a dictionary with "row_data", "global_key", "external_id" and "metadata_fields" keys
     """
-    row_data = base_client.upload_local_file(file_path=str(row[row_data_col])) if local_files else str(row[row_data_col])
+    row_data = lb_client.upload_file(str(row[row_data_col])) if local_files else str(row[row_data_col])
+#     row_data = base_client.upload_local_file(file_path=str(row[row_data_col])) if local_files else str(row[row_data_col])
     metadata_fields = [{"schema_id" : metadata_name_key_to_schema['lb_integration_source'], "value" : "Pandas"}]
     if metadata_index:
         for metadata_field_name in metadata_index.keys():
@@ -112,7 +115,7 @@ def add_column_function(df, column_name:str, default_value=""):
         column_name     :   Required (str) - Column name
         default_value   :   Optional - Value to insert into column
     Returns:
-        You Pandas DataFrame with a new column   
+        Your Pandas DataFrame with a new column   
     """
     df[column_name] = default_value
     return df
